*
* Example 10.1 from page 271
*
open data ex67.xls
calendar 1947 1 4
data(format=xls,org=columns) 1947:01 1995:03 gcq gydq
*
* You're generally able to write formulas for non-linear least
* squares in a natural fashion. The nonlin instruction is used
* to inform RATS of what parameters you will be estimating. You
* create the formula using the instruction FRML. The syntax for
* this is
*
*  FRML name of formula  dependent variable  = right hand side formula
*
nonlin a0 a1 a2
frml cfrml gcq = a0+a1*gydq**a2
*
* Non-linear models are estimated by least squares using the NLLS
* instruction. Before doing this, you should give initial guess
* values for the parameters. If you don't, the default starting
* values are zeros. In many cases, that may be fine, but here, if
* a1 is zero, a2 has no effect, and if a2 is zero, a1 will be applying
* to a series of 1's and thus won't be distinguishable from a0.
*
compute a0=a1=a2=1.0
nlls(frml=cfrml,iters=100)
*
* After the estimation, a0, a1 and a2 will be equal to the
* estimated values, so we can use those to compute the estimates
* of the MPC'.s
*
stats gydq
disp 'MPC at ' %mean 'is' a1*a2*%mean**(a2-1)
disp 'MPC at 600 is' a1*a2*600**(a2-1)
*
* You can do the restricted model using linreg.
*
linreg gcq
# constant gydq
*
* Or, you can adjust the nonlinear parameter set to fix a2 at 1.
*
nonlin a0 a1 a2=1.0
nlls(frml=cfrml,iters=100)


