*
* Example 10.4 from page 288
*
open data ex104.xls
calendar 1950 1 12
data(format=xls,org=columns) 1950:01 1996:02 raaa r3 ip gip pw gpw
*
graph(header='Figure 10.1 Three Month Treasury Bill Rate and AAA Corporate Bond Rate',$
  key=attached,klabels=||'Bill Rate','AAA Bond Rate'||) 2
# r3 1960:1 *
# raaa 1960:1 *
*
linreg raaa 1960:1 *
# constant r3{0 1 2} ip{0 1} gpw raaa{1}
graph(header='Figure 10.2 Residuals of AAA bond rate regression')
# %resids
*
* The results for the GARCH model in the text are incorrect - the program
* being used (which was not RATS) wasn't able to make progress from the
* initial guess values for the GARCH estimation, which is why the coefficients
* are so similar to the least squares.
*
* GARCH estimation is done using the instruction GARCH. The orders for the
* GARCH components are input using the options q (for the number of lagged
* squared residuals) and p (for the number of lagged variance terms). In the
* most typical use of GARCH, there are no regressors, just an estimated mean.
* Here, we have a regression equation which supplies the mean. Because the
* default behavior is just the simple mean, we need to use the option REGRESSORS
* to indicate that we need a full regression for the mean model. When you
* use that, just include the regressors on a supplementary card. This use
* of GARCH also has some extra options to add with the non-linear estimation.
* The PMETHOD option indicates a preliminary estimation method; in this case,
* the simplex method, which is a slow, but steady, method to try to get the
* parameters started up the "hill." The main estimation method (which is a
* derivative based algorithm known as BFGS) takes over after that.
*
* GARCH has a somewhat different syntax than most of the regression instructions
* that you've seen so far because it also handles multivariate GARCH models. Thus,
* the estimation range comes first so the end of the instruction is free for a list
* with more than one variable.
*
garch(regressors,p=1,q=1,iters=200,pmethod=simplex,piters=25) 1960:1 * raaa
# constant r3{0 1 2} ip{0 1} gpw raaa{1}
*
* It turns out that the addition of the extra variable to the GARCH equation
* really doesn't help when the estimates work out correctly. However, we'll
* show how to do this. To add additional variables to the variance, include
* the XREGRESSORS option. (This type of model is sometimes called a GARCH-X,
* hence the option name.) Use a second supplementary card to provide those
* variables.
*
set dr3 = r3-r3{1}
garch(regressors,xregressors,p=1,q=1,iters=200,pmethod=simplex,piters=25) 1960:1 * raaa
# constant r3{0 1 2} ip{0 1} gpw raaa{1}
# dr3{1}

