*
* Example 13.1, page 401
*
open data ex131.xls
calendar 1979 1 12
all 1988:06
data(format=xls,org=columns) 1979:01 1988:06 ip nho pho qho
*
* The results won't match (exactly) the ones shown in the text.
* The IP variable was added to the data set after the fact, and
* appears not to be the same one used in preparing the estimates.
* (Historical data for seasonally adjusted data such as IP can
*  be changed for up to five years. Series such as GDP can change
*  even more dramatically when they are rebenchmarked).
*
set gip = ip/ip{1}-1
*
* The SYSTEM instruction and its subinstructions define a VAR.
* VARIABLES lists the endogenous variables, DET (short for
* deterministic) the exogenous variables.
*
system(model=oil)
variables pho qho nho
lags 1 to 8
det gip constant
end(system)
*
* The last defined model is estimated with the ESTIMATE instruction.
* Here, we want estimation to start with 1980:1. (Given the data,
* we actually could start in 1979:9 allowing for the eight lags)
*
estimate 1980:1 *
*
* Dynamic forecasts of a multi-equation model are done using
* the FORECAST instruction. These are, of course, not exactly
* "fore"casts, since they're done over a period where we have
* data. The forecasts of the three variables go into the series
* forecast(1),forecast(2) and forecast(3).
*
smpl 1980:1 1988:6
forecast(model=oil,results=forecast)
*
* This graphs the forecasts over the entire range of the data.
* You'll note that the model seems surprisingly good at forecasting
* events well into the data set. This is all the more remarkable
* because the forecasts are computed using only data prior to 1980.
* However, the reason that VAR's estimated with OLS often show this
* in-sample forecasting prowess is that they have so many freely
* estimated parameters (78 in this case). This produces the well-known
* "overfitting" behavior, where a model can explain the data used
* for estimation quite well, while doing a poor job forecasting out
* of sample. For forecasting purposes, VAR's are usually estimated
* with a prior.
*
graph(header='Figure 13.17. Price of Heating Oil: actual vs simulated',$
  key=attached,klabels=||'Actual','Simulated'||) 2
# pho
# forecast(1)
*
smpl 1988:1 1988:6
forecast(model=oil,results=forecast)
*
graph(header='Figure 13.18. Price of Heating Oil: actual vs forecast',$
  key=attached,klabels=||'Actual','Forecast'||) 2
# pho
# forecast(1)
*
graph(header='Figure 13.19. Production of Heating Oil: actual vs forecast',$
  key=attached,klabels=||'Actual','Forecast'||) 2
# qho
# forecast(2)
*
graph(header='Figure 13.20. Inventory of Heating Oil: actual vs forecast',$
  key=attached,klabels=||'Actual','Forecast'||) 2
# nho
# forecast(3)




