*
* Example 18.3 from page 572
*
open data ex161.xls
calendar 1960 1 12
data(format=xls,org=columns) 1960:01 1996:03 fygn3
*
* While the BOXJENK instruction can automatically incorporate
* differencing into the estimation, most of the graphs in this
* example are of the differenced series, so we'll estimate
* the model after differencing the data ourselves. In order
* to forecast with the results of the BOXJENK, you need to
* define a linear equation from it, and you need to save
* the residuals.
*
set dr = fygn3-fygn3{1}
*
boxjenk(ar=8,ma=4,constant,define=a84) dr / resids
*
* With that being done, the UFORECAST instruction handles
* the forecasting. You just need to provide the name of
* the equation that you're forecasting.
*
uforecast(equation=a84) fore24 1994:4 1996:3
uforecast(equation=a84) fore12 1995:4 1996:3
uforecast(equation=a84) fore06 1995:10 1996:3
*
graph(header='Figure 18.7 Monthly Changes in Treasury Bill Rate, 24 Month Forecast vs Actual',$
  key=attached,klabels=||'Forecast','Actual'||) 2
# fore24
# dr 1994:4 1996:3
graph(header='Figure 18.8 Monthly Changes in Treasury Bill Rate, 12 Month Forecast vs Actual',$
  key=attached,klabels=||'Forecast','Actual'||) 2
# fore12
# dr 1995:4 1996:3
graph(header='Figure 18.9 Monthly Changes in Treasury Bill Rate, 12 Month Forecast vs Actual',$
  key=attached,klabels=||'Forecast','Actual'||) 2
# fore06
# dr 1995:10 1996:3
*
* There are several ways to get the forecasts of the level
* rather than difference. Ordinarily, you would just estimate
* the model with boxjenk with the DIFFS=1 option and the level
* of the series as the dependent variable. If you do that, the
* equation defined will be one to forecast the level.
*
boxjenk(diffs=1,ar=8,ma=4,constant,define=a814) fygn3 / resids
uforecast(equation=a814) fore06l 1995:10 1996:3
*
* There is also a MODIFY instruction which can be used to substitute out
* variables in an equation that has already been created.
*
modify a84 a814
vreplace dr with fygn3 diff 1
uforecast(equation=a814) fore06l 1995:10 1996:3
*
* Or, you can just take the forecasts of the changes and accumulate
* them. You then have to add in the final observed value of the
* level series.
*
accum fore06 1995:10 1996:3 fore06l
set fore06l 1995:10 1996:3 = fore06l+fygn3(1995:9)
*
graph(header='Figure 18.10 Three Month Treasury Bill Rate, 6 Month Forecast vs Actual') 2
# fygn3 1995:10 1996:3
# fore06l


